@@ -1,45 +1,36 @@
-use 5.008;
-use strict;
-use warnings;
-
 package Getopt::Attribute;
-our $VERSION = '1.100860';
-# ABSTRACT: Attribute wrapper for Getopt::Long
+
 use Getopt::Long;
 use Attribute::Handlers;
 
-sub UNIVERSAL::Getopt : ATTR(RAWDATA,BEGIN) {
-    my ($ref, $data) = @_[ 2, 4 ];
-    our %options;
+our $VERSION = '1.41';
 
+sub UNIVERSAL::Getopt : ATTR(RAWDATA,BEGIN) {
+	my ($ref, $data) = @_[2,4];
+	our %options;
     # this has to be an array as we're chasing refs later
-    if ($data =~ m/^(\S+)\s+(.*)/) {
+    if ($data =~ m/^(\S+)\s+(.*)/) {    
         $data = $1;
         push our @defaults, [ $ref => $2 ];
     }
-    $options{$data} = $ref;
+	$options{$data} = $ref;
 }
+
 INIT {
-    our $error = 0;
-    GetOptions(our %options) or $error = 1;
-    defined ${ $_->[0] } or ${ $_->[0] } = $_->[1] for our @defaults;
+    GetOptions(our %options);
+    defined ${$_->[0]} or ${$_->[0]} = $_->[1] for our @defaults;
 }
+
 sub options { our %options }
-sub error   { our $error }
+
 1;
 
-
 __END__
-=pod
 
 =head1 NAME
 
 Getopt::Attribute - Attribute wrapper for Getopt::Long
 
-=head1 VERSION
-
-version 1.100860
-
 =head1 SYNOPSIS
 
   use Getopt::Attribute;
@@ -52,12 +43,13 @@ version 1.100860
   our %defines : Getopt(define=s);
   sub quiet : Getopt(quiet) { our $quiet_msg = 'seen quiet' }
   usage() if our $man : Getopt(man);
+  ...
 
   # Meanwhile, on some command line:
-  #
-  # mypgm.pl --noverbose --all --size=23 --more --more --more --quiet
-  #          --library lib/stdlib --library lib/extlib
-  #          --define os=linux --define vendor=redhat --man -- foo
+
+  mypgm.pl --noverbose --all --size=23 --more --more --more --quiet
+           --library lib/stdlib --library lib/extlib
+           --define os=linux --define vendor=redhat --man -- foo
 
 =head1 DESCRIPTION
 
@@ -84,59 +76,39 @@ Instead, you have to establish defaults afterwards, like so:
 	our $verbose : Getopt(verbose!);
 	$verbose ||= 1;
 
-Alternatively, you can specify a default value within the C<Getopt>
+Alternatively, you can specify a default value within the Getopt
 attribute:
 
     our $def2 : Getopt(def2=i 42);
 
-To check whether there was an error during C<getopt> processing you can use
-the C<error()> function:
-
-    pod2usage(-verbose => 2, -exitval => 0) if Getopt::Attribute->error;
-
-=head1 METHODS
-
-=head2 error
-
-FIXME
-
-=head2 options
-
-FIXME
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Getopt-Attribute>.
+Please report any bugs or feature requests to
+C<bug-getopt-attribute@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see
-L<http://search.cpan.org/dist/Getopt-Attribute/>.
-
-The development version lives at
-L<http://github.com/hanekomu/Getopt-Attribute/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHOR
 
-  Marcel Gruenauer <marcel@cpan.org>
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2001 by Marcel Gruenauer.
+Copyright 2001-2007 by Marcel GrE<uuml>nauer
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
